/**
 * Copyright schukai GmbH and contributors 2023. All Rights Reserved.
 * Node module: @schukai/component-form
 * This file is licensed under the AGPLv3 License.
 * License text available at https://www.gnu.org/licenses/agpl-3.0.en.html
 */

import {extend} from "@schukai/monster/source/data/extend.mjs";
import {isArray} from "@schukai/monster/source/types/is.mjs";
import {validateBoolean} from "@schukai/monster/source/types/validate.mjs";


export {setEventListenersModifiers,  popperInstanceSymbol};

/**
 * @private
 * @type {symbol}
 */
const popperInstanceSymbol = Symbol("popperInstance");

/**
 * @private
 * @this {CustomElement}
 * @param {Boolean} mode
 */
function setEventListenersModifiers(mode) {
    const self = this;

    let options = extend({}, self.getOption("popper"));
    let modifiers = options?.["modifiers"];

    if (!isArray(modifiers)) {
        options["modifiers"] = [];
    }

    if (
        options["modifiers"].filter((entry) => {
            if (entry?.["name"] === "eventListeners") {
                // performance https://popper.js.org/docs/v2/tutorial/#performance
                entry["enabled"] = validateBoolean(mode);
            }
        }).length === 0
    ) {
        options["modifiers"].push({name: "eventListeners", enabled: validateBoolean(mode)});
    }

    self[popperInstanceSymbol].setOptions(options);
}

