'use strict';

import {getGlobal} from "@schukai/monster/source/types/global.mjs";
import Storage from "dom-storage";

export const isBrowser = new Function("try {return this===window;}catch(e){ return false;}");

export const isNode = new Function("try {return this===global;}catch(e){return false;}");




/**
 * this helper function creates the dom stack in the node environment
 *
 * @return {Promise<unknown>|Promise<void>}
 */
function initJSDOM() {
    if (typeof window === "object" && window['DOMParser']) return Promise.resolve();


    const g = getGlobal();

    const options = {
        pretendToBeVisual: true,
        contentType: "text/html",
        includeNodeLocations: true,
        storageQuota: 10000000,
        runScripts: "dangerously",
        resources: "usable"
    }

    return import("jsdom").then(({JSDOM}) => {
        const {window} = new JSDOM(`<html>
<head>
</head>
<body>
<div id="mocks"></div>
</body>`, options);

        g['window'] = window;

        return new Promise(resolve =>
            window.addEventListener("load", () => {

                [
                    'self',
                    'HTMLCollection',
                    'NodeList',
                    'ElementInternals',
                    'HTMLDocument',
                    'HTMLFormElement',
                    'HTMLInputElement',
                    'HTMLScriptElement',
                    'HTMLSelectElement',
                    'HTMLTextAreaElement',
                    'document',
                    'Document',
                    'Node',
                    'ShadowRoot',
                    'Event',
                    'HTMLButtonElement',
                    'CustomEvent',
                    'Element',
                    'HTMLElement',
                    'HTMLDivElement',
                    'customElements',
                    'DocumentFragment',
                    'DOMParser',
                    'CSSStyleSheet',
                    'MutationObserver',
                    'HTMLTemplateElement',
                    'getComputedStyle',
                    'XMLSerializer',
                    'NodeFilter',
                    'navigator',
                    'InputEvent',
                    'Blob',
                    'CustomEvent'
                ].forEach(key => {
                    g[key] = window[key]
                });

                g.localStorage = new Storage(null, { strict: true });
                g.sessionStorage = new Storage(null, { strict: true });

                window['localStorage'] = g.localStorage;
                window['sessionStorage'] = g.sessionStorage;

                resolve(g);
            })
        );


    });
}

export {initJSDOM}

